==> gnome-control-center-2.20.3-i586-1gsb.tgz: install/doinst.sh <==
( cd usr/lib ; rm -rf libgnome-window-settings.so )
( cd usr/lib ; ln -sf libgnome-window-settings.so.1.0.0 libgnome-window-settings.so )
( cd usr/lib ; rm -rf libgnome-window-settings.so.1 )
( cd usr/lib ; ln -sf libgnome-window-settings.so.1.0.0 libgnome-window-settings.so.1 )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/apps_gnome_settings_daemon_default_editor.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/apps_gnome_settings_daemon_keybindings.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/apps_gnome_settings_daemon_screensaver.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/control-center.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/desktop_gnome_font_rendering.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/fontilus.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/themus.schemas >/dev/null 2>&1
fi
## Doinst for gnome-control-panel

ldconfig -r .

function install_file() {
  # $1 = File to process

  FILE="$(dirname "$1")/$(basename "$1" .new)"
  if [ ! -e "$FILE" ]
  then
    mv "$FILE.new" "$FILE"
  elif [ "$(cat "$FILE" | md5sum)" != "$(cat "$FILE.new" | md5sum)" ]
  then
    #     |--------|--------------------------------------------------|
    echo "WARNING: $FILE has been customised."
    echo "         Examine the $FILE.new file"
    echo "         and integrate any changes into the custom file."
    echo
  else
    rm -f "$FILE.new"
  fi
}

install_file etc/xdg/menus/gnomecc.menu.new

if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

## Allow users to modify the list of user-specified or Favorite applications
if [ -x usr/bin/gconftool-2 ]; then
    usr/bin/gconftool-2 --direct --config-source=`usr/bin/gconftool-2 --get-default-source` --type string --set /desktop/gnome/applications/main-menu/lock-down/user_modifiable_apps True >/dev/null 2>&1
fi;

==> gnome-control-center-2.22.1-i586-1gsb.tgz: install/doinst.sh <==
( cd usr/lib ; rm -rf libgnome-window-settings.so )
( cd usr/lib ; ln -sf libgnome-window-settings.so.1.0.0 libgnome-window-settings.so )
( cd usr/lib ; rm -rf libgnome-window-settings.so.1 )
( cd usr/lib ; ln -sf libgnome-window-settings.so.1.0.0 libgnome-window-settings.so.1 )

if [ -x usr/bin/gconftool-2 ]; then
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/control-center.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/fontilus.schemas >/dev/null 2>&1
GCONF_CONFIG_SOURCE="$(usr/bin/gconftool-2 --get-default-source)" usr/bin/gconftool-2 --makefile-install-rule etc/gconf/schemas/themus.schemas >/dev/null 2>&1
fi
## Doinst for gnome-control-panel

ldconfig -r .

function install_file() {
  # $1 = File to process

  FILE="$(dirname "$1")/$(basename "$1" .new)"
  if [ ! -e "$FILE" ]
  then
    mv "$FILE.new" "$FILE"
  elif [ "$(cat "$FILE" | md5sum)" != "$(cat "$FILE.new" | md5sum)" ]
  then
    #     |--------|--------------------------------------------------|
    echo "WARNING: $FILE has been customised."
    echo "         Examine the $FILE.new file"
    echo "         and integrate any changes into the custom file."
    echo
  else
    rm -f "$FILE.new"
  fi
}

install_file etc/gnome/xdg/menus/gnomecc.menu.new

if [ -x usr/bin/rarian-sk-update ]; then
  usr/bin/rarian-sk-update 1> /dev/null 2> /dev/null
fi

if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

## Allow users to modify the list of user-specified or Favorite applications
if [ -x usr/bin/gconftool-2 ]; then
    usr/bin/gconftool-2 --direct --config-source=`usr/bin/gconftool-2 --get-default-source` --type string --set /desktop/gnome/applications/main-menu/lock-down/user_modifiable_apps True >/dev/null 2>&1
fi;

# Restart gconfd-2 if running to reload new gconf settings
if ps acx | grep -q gconfd-2 ; then
        killall -HUP gconfd-2 ;
fi
